@@ -6,6 +6,8 @@ import numpy as np
 import seaborn as sns
 import matplotlib.pyplot as plt
 
+from scipy.interpolate import make_interp_spline, BSpline
+
 sns.set_theme()
 sns.set_context("paper")
 
@@ -173,4 +175,81 @@ def seasonal_decompose(data, intervention, figsize=(18, 12)):
         sns.lineplot(x = data.index, y = data[name], color = 'b', ax=axes[number], linewidth=1, label = name)
     
     # Show the plot
-    sns.despine()
\ No newline at end of file
+    sns.despine()
+
+def sensitivity_curve(arr1 = None, arr2 = None, area = None, figsize=(25, 8)):
+    # create the plot
+    fig, ax = plt.subplots(figsize = figsize)
+
+    # plot the markers
+    sns.scatterplot(x=arr1, y=arr2, ax=ax, s=100, color='grey', label='P-Value')
+
+    # interpolate the line using a spline
+    x_new = np.linspace(arr1.min(), arr1.max(), 300)
+    spl = make_interp_spline(arr1, arr2, k=3)  # k=3 for cubic spline
+    y_smooth = spl(x_new)
+
+    # plot the interpolated line
+    ax.plot(x_new, y_smooth, color='violet', linewidth=3, label='Effect')
+
+    bbox_props = dict(boxstyle='round,pad=0.5', fc='white', ec='gray', lw=1) # set the box properties
+    ax.text(1.0, 0.4, f'Sensitivity: {area:.2f}', fontsize=14, bbox=bbox_props) # add the text box annotation to the plot
+
+    # add axis labels and a title
+    ax.set_xlabel('Estimated Effect', fontsize=14)
+    ax.set_ylabel('P-Value', fontsize=14)
+    ax.set_title('Minimum Detectable Effect over Time Series', fontsize=18)
+
+    # add a legend
+    ax.legend(fontsize=12)
+
+    # add x-axis and y-axis ticks and tick labels
+    ax.tick_params(axis='both', labelsize=12)
+    ax.xaxis.set_major_locator(plt.MultipleLocator(0.1))
+    ax.xaxis.set_minor_locator(plt.MultipleLocator(0.05))
+
+    ax.yaxis.set_major_locator(plt.MultipleLocator(0.1))
+    ax.yaxis.set_minor_locator(plt.MultipleLocator(0.05))
+
+    idx = np.argmax(arr2 < 0.05)
+    ax.axvline(x=arr1[idx], linestyle='--', color='gray')
+
+    plt.show()
+
+def plot_training(data, past_window: int = 5, back_window: int = 25, figsize=(15, 10), intervention = None):
+        data = data.copy()
+        fig, axes = plt.subplots(nrows=1, ncols=1, figsize=figsize)
+
+        lineplot = sns.lineplot(x = 'ds', y = 'yhat', color = 'r', alpha=0.5, linestyle='--', ci=95,
+                            err_kws={'linestyle': '--', 'hatch': '///', 'fc': 'none'}, ax=axes[0],
+                    data = data[(data.ds >= pd.to_datetime(intervention[0]) - pd.Timedelta(days=back_window))&(data.ds <= pd.to_datetime(intervention[1]) + pd.Timedelta(days=past_window))]
+                    )
+
+        sns.lineplot(x = 'ds', y = 'y', ax=axes[0], color = 'b',
+                    data = data[(data.ds >= pd.to_datetime(intervention[0]) - pd.Timedelta(days=back_window))&(data.ds <= pd.to_datetime(intervention[1]) + pd.Timedelta(days=past_window))]
+                    )
+
+        lineplot.axvline(pd.to_datetime(intervention[0]), color='r', linestyle='--',alpha=.5)
+        lineplot.axvline(pd.to_datetime(intervention[1]), color='r', linestyle='--',alpha=.5)
+
+        lineplot.fill_between(data[(data.ds >= pd.to_datetime(intervention[0]) - pd.Timedelta(days=back_window))&(data.ds <= pd.to_datetime(intervention[1]) + pd.Timedelta(days=past_window))]['ds'], 
+                        data[(data.ds >= pd.to_datetime(intervention[0]) - pd.Timedelta(days=back_window))&(data.ds <= pd.to_datetime(intervention[1]) + pd.Timedelta(days=past_window))]['yhat_lower'],
+                        data[(data.ds >= pd.to_datetime(intervention[0]) - pd.Timedelta(days=back_window))&(data.ds <= pd.to_datetime(intervention[1]) + pd.Timedelta(days=past_window))]['yhat_upper'], 
+                        color='r', alpha=.1)
+        
+        # Add horizontal lines for percentiles
+        perc_75 = np.percentile(data['y'], 75)
+        perc_25 = np.percentile(data['y'], 25)
+        median = np.percentile(data['y'], 50)
+
+        axes.axhline(y=perc_75, linestyle='--', color='grey', alpha=0.5)
+        axes.axhline(y=perc_25, linestyle='--', color='grey', alpha=0.5)
+        axes.axhline(y=median, linestyle='--', color='grey', alpha=0.5)
+
+        lineplot.legend(['Prediction', 'Real'])
+
+        axes.set_xlabel('Ds')
+        axes.set_ylabel('Y')
+        axes.set_title('Model fit in training and test period')
+
+        plt.show()
\ No newline at end of file
