@@ -10,6 +10,7 @@ import logging
 from tscausalinference.evaluators import mape
 from tscausalinference.regression import prophet_regression
 from tscausalinference.bootstrap import bootstrap_simulate, bootstrap_p_value
+from tscausalinference.synth_regression import synth_analysis
 
 logger = logging.getLogger('cmdstanpy')
 logger.addHandler(logging.NullHandler())
@@ -21,7 +22,7 @@ logging.getLogger('fbprophet').setLevel(logging.ERROR)
 pd.options.mode.chained_assignment = None 
 
 def training_model(df: DataFrame = pd.DataFrame(), 
-                         test_period = None, 
+                         training_period = None, 
                          cross_validation_steps: int = 5, 
                          alpha: float = 0.05, 
                          model_params: dict = {}, 
@@ -36,9 +37,9 @@ def training_model(df: DataFrame = pd.DataFrame(),
     elif df.empty:
         raise TypeError("df is empty")
 
-    if isinstance(test_period, type(None)):
-      test_period_error = 'Define your training_period as a list with the start_date and end_date of your TEST PERIOD'
-      raise TypeError(test_period_error)
+    if isinstance(training_period, type(None)):
+      training_period_error = 'Define your intervention as a list with the start_date and end_date of your TRAINING PERIOD'
+      raise TypeError(training_period_error)
     
     if len(model_params) < 1:
         model_parameters = {
@@ -55,11 +56,12 @@ def training_model(df: DataFrame = pd.DataFrame(),
     else:
         model_parameters = model_params.copy()
     
-    training_period = [df.ds.min(), (pd.to_datetime(test_period[0]) - pd.Timedelta(days=1)).strftime('%Y-%m-%d')]
+    start_date = (pd.to_datetime(training_period[0])).strftime('%Y-%m-%d')
+    end_date = (pd.to_datetime(training_period[1])).strftime('%Y-%m-%d')
     
-    data, paremeters = prophet_regression(
+    data = prophet_regression(
             df = df, 
-            intervention = test_period, 
+            intervention = training_period, 
             cross_validation_steps = cross_validation_steps, 
             alpha = alpha, 
             model_params = model_parameters, 
@@ -70,10 +72,10 @@ def training_model(df: DataFrame = pd.DataFrame(),
     data['residuals'] = data['y'] - data['yhat']
     
     training_results = [
-    ['r2', r2_score(y_pred = data[(data.ds >= pd.to_datetime(training_period[0]))&(data.ds <= pd.to_datetime(training_period[1]))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(training_period[0]))&(data.ds <= pd.to_datetime(training_period[1]))&(data.y > 0)].y)],
-    ['MAE', mean_absolute_error(y_pred = data[(data.ds >= pd.to_datetime(training_period[0]))&(data.ds <= pd.to_datetime(training_period[1]))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(training_period[0]))&(data.ds <= pd.to_datetime(training_period[1]))&(data.y > 0)].y)],
-    ['MAPE (%)', mape(y_pred = data[(data.ds >= pd.to_datetime(training_period[0]))&(data.ds <= pd.to_datetime(training_period[1]))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(training_period[0]))&(data.ds <= pd.to_datetime(training_period[1]))&(data.y > 0)].y)],
-    ['Noise (Std)', np.std(data[(data.ds >= pd.to_datetime(training_period[0]))&(data.ds <= pd.to_datetime(training_period[1]))&(data.y > 0)].y - data[(data.ds >= pd.to_datetime(training_period[0]))&(data.ds <= pd.to_datetime(training_period[1]))&(data.y > 0)].yhat)]
+    ['r2', r2_score(y_pred = data[(data.ds >= pd.to_datetime(start_date))&(data.ds <= pd.to_datetime(end_date))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(start_date))&(data.ds <= pd.to_datetime(end_date))&(data.y > 0)].y)],
+    ['MAE', mean_absolute_error(y_pred = data[(data.ds >= pd.to_datetime(start_date))&(data.ds <= pd.to_datetime(end_date))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(start_date))&(data.ds <= pd.to_datetime(end_date))&(data.y > 0)].y)],
+    ['MAPE (%)', mape(y_pred = data[(data.ds >= pd.to_datetime(start_date))&(data.ds <= pd.to_datetime(end_date))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(start_date))&(data.ds <= pd.to_datetime(end_date))&(data.y > 0)].y)],
+    ['Noise (Std)', np.std(data[(data.ds >= pd.to_datetime(start_date))&(data.ds <= pd.to_datetime(end_date))&(data.y > 0)].y - data[(data.ds >= pd.to_datetime(start_date))&(data.ds <= pd.to_datetime(end_date))&(data.y > 0)].yhat)]
     ]
 
     strings_info = """
@@ -93,14 +95,10 @@ def training_model(df: DataFrame = pd.DataFrame(),
         )
 
     test_results = [
-    ['r2', r2_score(y_pred = data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].yhat, y_true = data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].y)],
-    ['MAE', mean_absolute_error(y_pred = data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].yhat, y_true = data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].y)],
-    ['MAPE (%)', mape(y_pred = data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].yhat, y_true = data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].y)],
-    ['Noise (Std)', np.std(data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].y - data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].yhat)],
-    ['Actual cumulative', data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].y.sum()],
-    ['Predicted cumulative:', data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].yhat.sum()],
-    ['Difference', data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].point_effects.sum()],
-    ['Change (%)', (data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].y.sum() / data[(data.ds >= test_period[0]) & (data.ds <= test_period[1])].yhat.sum() - 1) * 100]
+    ['r2', r2_score(y_pred = data[(data.ds > pd.to_datetime(end_date))&(data.y > 0)].yhat, y_true = data[(data.ds > pd.to_datetime(end_date))&(data.y > 0)].y)],
+    ['MAE', mean_absolute_error(y_pred = data[(data.ds > pd.to_datetime(end_date))&(data.y > 0)].yhat, y_true = data[(data.ds > pd.to_datetime(end_date))&(data.y > 0)].y)],
+    ['MAPE (%)', mape(y_pred = data[(data.ds > pd.to_datetime(end_date))&(data.y > 0)].yhat, y_true = data[(data.ds > pd.to_datetime(end_date))&(data.y > 0)].y)],
+    ['Noise (Std)', np.std(data[(data.ds > pd.to_datetime(end_date))&(data.y > 0)].y - data[(data.ds > pd.to_datetime(end_date))&(data.y > 0)].yhat)]
     ]
 
     strings_info = """
@@ -118,7 +116,7 @@ def training_model(df: DataFrame = pd.DataFrame(),
             ).strip()
         )
     
-    return data, training_results, test_results, paremeters
+    return data, training_results, test_results, model_parameters
 
 def sensitivity_analysis(df: DataFrame = pd.DataFrame(), 
                          test_period = None, 
@@ -133,28 +131,34 @@ def sensitivity_analysis(df: DataFrame = pd.DataFrame(),
         df_temp = df.copy()
         
         data, training, test, model_parameters = training_model(
-                df = df_temp, 
-                regressors = regressors, 
-                test_period = test_period, 
-                cross_validation_steps = cross_validation_steps,
-                alpha = alpha,
-                model_params = model_params,
-                verbose = verbose,
-                model_type = model_type
-                )
+            df = df_temp, 
+            regressors = regressors, 
+            training_period = test_period, 
+            cross_validation_steps = cross_validation_steps,
+            alpha = alpha,
+            model_params = model_params,
+            verbose = verbose
+            )
         
         effects = np.linspace(1.0, 2.0, 30)
         e_dataframe = pd.DataFrame()
+    
+        data, pre_int_metrics, int_metrics = synth_analysis(
+            df = df_temp, 
+            regressors = regressors, 
+            intervention = test_period, 
+            cross_validation_steps = cross_validation_steps,
+            alpha = alpha,
+            model_params = model_parameters,
+            verbose = True
+            )
 
         for effect in effects:
             temp_test = data.copy()
 
             # create a boolean mask for the rows in the test period
             test_mask = (temp_test['ds'] >= pd.to_datetime(test_period[0])) & (temp_test['ds'] <= pd.to_datetime(test_period[1]))
-            
-            #mask last 90 days
-            rolling_mask = (temp_test['ds'] >= (pd.to_datetime(test_period[0]) - pd.Timedelta(days = 89))) & (temp_test['ds'] < pd.to_datetime(test_period[0]))
-            
+
             # multiply 'y' by 1.1 in the test period
             temp_test.loc[test_mask, 'y'] *= effect
             
@@ -167,23 +171,14 @@ def sensitivity_analysis(df: DataFrame = pd.DataFrame(),
             stadisticts, stats_ranges, samples_means = bootstrap_p_value(control = temp_test[test_mask].yhat, 
                                                                                         treatment = temp_test[test_mask].y, 
                                                                                         simulations = simulations,
-                                                                                        mape = abs(round(test[2][1],6))/100
+                                                                                        mape = abs(round(pre_int_metrics[2][1],6))/100
                                                                                         )
             
-            results_df = pd.DataFrame({
-                            'injected_effect': [round(effect, 2)],
-                            'model': [model_parameters],
-                            'pvalue': [stadisticts[0]],
-                            'train': [training], 
-                            'test': [test],
-                            'ci_lower': [temp_test.yhat_lower.sum() * (1 - (abs(round(test[2][1],6)) / 100))],
-                            'ci_upper': [temp_test.yhat_upper.sum() * (1 + (abs(round(test[2][1],6)) / 100))],
-                            'y_test_period': [temp_test[test_mask].y.sum()],
-                            'y_test_period_mean': [temp_test[test_mask].y.mean()],
-                            'y_last90days_mean': [temp_test[rolling_mask].y.mean()],
-                            'y_historical_mean': [temp_test[temp_test['ds'] < pd.to_datetime(test_period[0])].y.mean()]
-                            })
+            results_df = pd.DataFrame({'injected_effect':[round(effect,2)], 'model':[model_parameters], 'pvalue':[stadisticts[0]], 'train': [training], 
+                                       'test_': [test], 'intervention': [int_metrics], 'confidence_interval':[stats_ranges],
+                                       'mean_intervention': [temp_test[test_mask].y.mean()],'mean_pre_intervention': [temp_test[temp_test['ds'] < pd.to_datetime(test_period[0])].y.mean()] 
+                                       })
             
             e_dataframe = pd.concat([e_dataframe, results_df])
 
-        return e_dataframe.set_index('injected_effect'), model_parameters
\ No newline at end of file
+        return e_dataframe
\ No newline at end of file
